@@ -1,5 +1,5 @@
 from finvizfinance.screener.overview import Overview
-from finvizfinance.util import webScrap
+from finvizfinance.util import webScrap, progressBar
 """
 .. module:: screen.ticker
    :synopsis: screen ticker table.
@@ -7,6 +7,7 @@ from finvizfinance.util import webScrap
 .. moduleauthor:: Tianning Li <ltianningli@gmail.com>
 """
 
+
 class Ticker(Overview):
     """Financial inherit from overview module.
     Getting information from the finviz screener ticker page.
@@ -15,7 +16,7 @@ class Ticker(Overview):
         """initiate module
         """
         self.BASE_URL = 'https://finviz.com/screener.ashx?v=411{signal}{filter}&ft=4{ticker}'
-        self.url = self.BASE_URL.format(signal='', filter='',ticker='')
+        self.url = self.BASE_URL.format(signal='', filter='', ticker='')
         Overview._loadSetting(self)
 
     def _screener_helper(self, i, page, soup, tickers, limit):
@@ -46,14 +47,14 @@ class Ticker(Overview):
                 page = (limit-1)//1000+1
 
         if verbose == 1:
-            print('[Info] loading page 1/{} ...'.format(page))
+            progressBar(1, page)
 
         tickers = []
         tickers = self._screener_helper(0, page, soup, tickers, limit)
 
         for i in range(1, page):
             if verbose == 1:
-                print('[Info] loading page {}/{} ...'.format((i + 1), page))
+                progressBar(i+1, page)
             soup = webScrap(self.url + '&r={}'.format(i * 1000 + 1))
             tickers = self._screener_helper(i, page, soup, tickers, limit)
         return tickers
\ No newline at end of file
