@@ -1,6 +1,7 @@
 import requests
 import pandas as pd
 from bs4 import BeautifulSoup
+import sys
 
 """
 .. module:: util
@@ -12,6 +13,7 @@ from bs4 import BeautifulSoup
 headers = {'User-Agent': 'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_15_4) \
             AppleWebKit/537.36 (KHTML, like Gecko) Chrome/81.0.4044.138 Safari/537.36'}
 
+
 def webScrap(url):
     """Scrap website.
 
@@ -28,6 +30,7 @@ def webScrap(url):
         raise SystemExit(err)
     return soup
 
+
 def imageScrap(url, ticker, out_dir):
     """scrap website and download image
 
@@ -41,13 +44,14 @@ def imageScrap(url, ticker, out_dir):
         r.raise_for_status()
         r.raw.decode_content = True
         if len(out_dir) != 0:
-            out_dir +='/'
+            out_dir += '/'
         f = open('{}{}.jpg'.format(out_dir, ticker), "wb")
         f.write(r.content)
         f.close()
     except requests.exceptions.HTTPError as err:
         raise SystemExit(err)
 
+
 def scrapFunction(url):
     """Scrap forex, crypto information.
 
@@ -74,6 +78,7 @@ def scrapFunction(url):
         df = df.append(info_dict, ignore_index=True)
     return df
 
+
 def imageScrapFunction(url, chart, timeframe, urlonly):
     """Scrap forex, crypto information.
 
@@ -110,6 +115,7 @@ def imageScrapFunction(url, chart, timeframe, urlonly):
         else:
             continue
 
+
 def numberCovert(num):
     """covert number(str) to number(float)
 
@@ -129,4 +135,12 @@ def numberCovert(num):
     elif num[-1] == 'K':
         return float(num[:-1]) * 1000
     else:
-        return float(''.join(num.split(',')))
\ No newline at end of file
+        return float(''.join(num.split(',')))
+
+
+def progressBar(page, total):
+    bar_len = 30
+    filled_len = int(round(bar_len * page / float(total)))
+    bar = '#' * filled_len + '-' * (bar_len - filled_len)
+    sys.stdout.write('[Info] loading page [{}] {}/{} \r'.format(bar, page, total))
+    sys.stdout.flush()
\ No newline at end of file
